/**
 * @description saofile
 */
const path = require('path')

module.exports = {
  templateDir: 'template',
  prompts() {
    return [
      {
        name: 'title',
        message: '组件的中文标题',
        default: this.outFolder,
        filter: val => val.toLowerCase(),
      },
      {
        name: 'name',
        message: '组件的英文名称',
        default: this.outFolder,
        filter: val => val.toLowerCase(),
      },
      {
        name: 'type',
        message: '组件类型：手机端组件或PC端组件',
        type: 'list',
        choices: ['mobile', 'pc'],
        default: 'mobile',
        filter: val => (val === 'mobile' ? 0 : 1),
      },
      {
        name: 'version',
        message: '组件版本号',
        default: 'v0.0.1',
        filter: val => val.toLowerCase(),
      },
      {
        name: 'username',
        message: '创建者姓名',
        default: this.gitUser.username || this.gitUser.name,
        filter: val => val.toLowerCase(),
        store: true,
      },
      {
        name: 'email',
        message: '联系邮件',
        default: this.gitUser.email,
        store: true,
      },
    ]
  },
  templateData() {
    return {
      npmURL: this.sao.opts.registry || 'https://registry.npm.taobao.org',
    }
  },
  actions: [
    {
      type: 'add',
      files: '**',
      transformExclude: '**/index.html',
      filters: {
        'saofile.js': false,
      },
    },
    {
      type: 'move',
      patterns: {
        _browserslistrc: '.browserslistrc',
        _gitignore: '.gitignore',
        _editorconfig: '.editorconfig',
        '_package.json': 'package.json',
        '_eslintrc.js': '.eslintrc.js',
      },
    },
  ],
  async completed(context) {
    let params = context._answers
    const pcIndex = path.join(context.outDir, 'public', 'pc.html')
    const wapIndex = path.join(context.outDir, 'public', 'index.html')
    // PC组件
    if (params.type === 1) {
      context.fs.unlinkSync(wapIndex)
      context.fs.renameSync(pcIndex, wapIndex)
    } else {
      // 无线组件
      context.fs.unlinkSync(pcIndex)
    }
    const pkgPath = path.join(context.outDir, 'package.json')
    if (await context.fs.pathExists(pkgPath)) {
      await context.npmInstall()
    }
    context.showProjectTips()
    context.gitInit()
  },
}
