/**
 *@description constant
 */
const Util = require("./util");
const fs = require("fs-extra");
const { join, dirname } = require("path");
const simpleGit = require("simple-git");

const ROOT = Util.getDir();
const DIST_DIR = Util.getDir("dist");
const SRC_DIR = Util.getDir("src");
const GIT = simpleGit(ROOT);
const packageFile = JSON.parse(fs.readFileSync(join(ROOT, "package.json")));

const moduleConfig = JSON.parse(
    fs.readFileSync(join(ROOT, "release", "config.json"))
);

GIT.branchLocal((err, branch) => {
    let data = fs.readdirSync(SRC_DIR);
    data.map((item) => {
        if (item.indexOf(".") > -1) {
            return;
        }
        moduleConfig.version = branch.current;
        moduleConfig.name = packageFile.name;
        moduleConfig.title = packageFile.title || packageFile.name;
        moduleConfig.module = packageFile.name;
        // 合并生成config文件
        let sourceFile = join(SRC_DIR, item, "config.json");
        if (!fs.existsSync(sourceFile)) {
            return;
        }
        let configFile,
            dir = join(DIST_DIR, item);
        try {
            configFile = JSON.parse(fs.readFileSync(sourceFile));
        } catch (error) {
            console.log(sourceFile);
            throw error;
        }
        if (!fs.existsSync(dir)) {
            fs.mkdirSync(dir);
        }
        configFile.name = item;
        configFile.version = branch.current;
        configFile.module = packageFile.name;
        fs.writeFileSync(
            join(dir, "config.json"),
            JSON.stringify(configFile, null, "\t")
        );
        moduleConfig.meta.push({
            name: item,
            title: configFile.title,
            master: !!configFile.master,
            tag: configFile.tag,
        });
        // 合并预览文件
        let previewFile = join(SRC_DIR, item, "preview.jpg");
        if (!fs.existsSync(previewFile)) {
            return;
        }
        fs.copyFileSync(previewFile, join(DIST_DIR, item, "preview.jpg"));
    });
    fs.writeFileSync(
        join(DIST_DIR, "index.json"),
        JSON.stringify(moduleConfig, null, "\t")
    );
    console.log("finished");
});
