const UglifyJsPlugin = require("uglifyjs-webpack-plugin");
const OptimizeCSSAssetsPlugin = require("optimize-css-assets-webpack-plugin");

module.exports = {
    production: "production",
    development: "development",
    mode: function (mode) {
        if (mode === this.production) {
            return mode;
        }
        return "development";
    },
    get: function (mode) {
        if (mode === this.production) {
            return {
                minimizer: [
                    new UglifyJsPlugin({
                        cache: true,
                        parallel: true,

                        sourceMap: false, // set to true if you want JS source maps
                        uglifyOptions: {
                            mangle: {
                                toplevel: false,
                            },
                            output: {
                                ascii_only: true
                            },
                            compress: {
                                global_defs: {
                                    'DEBUG': false
                                },
                                unused: true,
                                toplevel: true,
                                drop_debugger: true,
                                drop_console: true,
                                dead_code: true
                            }
                        }
                    }),
                    new OptimizeCSSAssetsPlugin({})
                ]
            }
        }
        return {}
    }
};